@@ -1,28 +1,28 @@
-if [ -f /etc/defaults/etc/WindowMaker/WindowMaker -a ! -f /etc/WindowMaker/WindowMaker ]
+if [ ! -f /etc/WindowMaker/WindowMaker ]
 then
     /usr/bin/mkdir -p /etc/WindowMaker
     /usr/bin/cp /etc/defaults/etc/WindowMaker/WindowMaker /etc/WindowMaker/WindowMaker
 fi
 
-if [ -f /etc/defaults/etc/WindowMaker/WMGLOBAL -a ! -f /etc/WindowMaker/WMGLOBAL ]
+if [ ! -f /etc/WindowMaker/WMGLOBAL ]
 then
     /usr/bin/mkdir -p /etc/WindowMaker
     /usr/bin/cp /etc/defaults/etc/WindowMaker/WMGLOBAL /etc/WindowMaker/WMGLOBAL
 fi
 
-if [ -f /etc/defaults/etc/WindowMaker/WMRootMenu -a ! -f /etc/WindowMaker/WMRootMenu ]
+if [ ! -f /etc/WindowMaker/WMRootMenu ]
 then
     /usr/bin/mkdir -p /etc/WindowMaker
     /usr/bin/cp /etc/defaults/etc/WindowMaker/WMRootMenu /etc/WindowMaker/WMRootMenu
 fi
 
-if [ -f /etc/defaults/etc/WindowMaker/WMState -a ! -f /etc/WindowMaker/WMState ]
+if [ ! -f /etc/WindowMaker/WMState ]
 then
     /usr/bin/mkdir -p /etc/WindowMaker
     /usr/bin/cp /etc/defaults/etc/WindowMaker/WMState /etc/WindowMaker/WMState
 fi
 
-if [ -f /etc/defaults/etc/WindowMaker/WMWindowAttributes -a ! -f /etc/WindowMaker/WMWindowAttributes ]
+if [ ! -f /etc/WindowMaker/WMWindowAttributes ]
 then
     /usr/bin/mkdir -p /etc/WindowMaker
     /usr/bin/cp /etc/defaults/etc/WindowMaker/WMWindowAttributes /etc/WindowMaker/WMWindowAttributes
@@ -30,4 +30,4 @@ fi
 
 case $(uname -s) in *-WOW*) wow64=" (32-bit)" ;; esac
 /usr/bin/mkdir -p "$(/usr/bin/cygpath $CYGWINFORALL -P)/Cygwin-X${wow64}"
-/usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/bin/XWin.exe -n "Cygwin-X${wow64}/WindowMaker" -a "--quote /usr/bin/bash.exe -l -c \"cd; /usr/bin/startx /etc/X11/xinit/Xsession WindowMaker\"" /usr/bin/run.exe
+/usr/bin/mkshortcut $CYGWINFORALL -P -w / -i /usr/share/pixmaps/xwin/WindowMaker.ico -n "Cygwin-X${wow64}/WindowMaker" -a "--quote /usr/bin/bash.exe -l -c \"cd; XSESSION_ICON=WindowMaker exec /usr/bin/startx /etc/X11/xinit/Xsession WindowMaker\"" /usr/bin/run.exe
